package PNI::Node::Perlfunc;

our $VERSION = '0.04.0';

1
__END__

=head1 NAME

PNI::Node::Perlfunc - PNI node collection

=head1 DESCRIPTION

It's a basic collection of PNI nodes implementing Perl functions.

=head1 SEE ALSO

L<PNI>

=cut

